# [Django Berry](https://app-generator.dev/docs/products/django-libs/theme-berry.html)

Modern template for **[Django Admin](https://app-generator.dev/docs/products/django-libs/theme-berry.html)**, Auth Pages (registration included) crafted on top of **Berry**, an open-source **Bootstrap** design.

- [Django Admin Berry](https://app-generator.dev/docs/products/django-libs/theme-berry.html) - **Documentation** & Support Links
- [Django Berry](https://app-generator.dev/product/berry-dashboard/django/) - The product that uses the library
- [Getting Started with Django](https://app-generator.dev/docs/technologies/django/index.html) - Learn how to code **Django** Projects

<br />

## **Features**

- Design: **[Berry](https://app-generator.dev/docs/templates/bootstrap/berry-dashboard.html)** (Bootstrap)
- **Sections Covered**: 
  - `Admin Section`, reserved for `superusers`
  - `All pages` managed by `Django.contrib.AUTH`
  - `Registration` page
  - `Misc pages`: colors, icons, typography, blank-page 
  
<br />

### Build a Starter with [Django App Generator - Berry Design](https://app-generator.dev/tools/django-generator/berry/)

- Access the [App Generator](https://app-generator.dev/tools/django-generator/) page
- Select **Berry Dashboard** as the preferred design
- (Optional) Design Database: edit models and fields
- (Optional) Edit the fields for the extended user model
- (Optional) Enable OAuth for GitHub
- (Optional) Add Celery (async tasks)
- (Optional) Enable Dynamic API Module
- Docker Scripts
- Render CI/Cd Scripts

**The generated Django project is available as a ZIP Archive and also uploaded to GitHub.**

<br />

![Django Berry - Modern template for Django Admin Section crafted on top of a modern Bootstrap, Open-Source Design.](https://user-images.githubusercontent.com/51070104/215728710-d1ee7fef-8153-402b-9741-371e1c01cd36.png)

<br />

## [Berry Dashboard PRO Version](https://app-generator.dev/product/berry-dashboard-pro/django/)

> The premium version provides more features, priority on support, and is more often updated - [Live Demo](https://django-berry-pro.onrender.com/dashboard/).

- **Simple, Easy-to-Extend** Codebase
- **Berry Dashboard** Design - PRO Version
- Bootstrap 5 CSS
- **OAuth** - Github
- **Extended User Profile**
- **API** via DRF 
- **Charts** via ApexJS 
- **Celery** (async tasks)
- **Deployment-Ready** for Render 

![Berry Bootstrap 5 PRO - Premium Template Django Template integrated with Django.](https://user-images.githubusercontent.com/51070104/215728155-9b9cfe26-96e8-49c3-8a08-131d96f4f2eb.png)

<br />

---
**[Django Berry](https://app-generator.dev/docs/products/django-libs/theme-berry.html)** - Modern Django Admin Interface provided by **[App-Generator](https://app-generator.dev)**
